@@ -46,17 +46,20 @@ var TIME = options.time,
     defaultColor = options.default_color,
     bdTitle = options.bd_title,
     bdSubtitle = options.bd_subtitle || subTitle,
+    bdAxisTitle = options.bd_axis_title,
     bdBarWidth = options.bd_bar_width || barWidth,
     bdPositiveColor = options.bd_positive_color || positiveColor,
     bdNegativeColor = options.bd_negative_color || negativeColor,
     bdDefaultColor = options.bd_default_color || defaultColor,
     svTitle = options.sv_title,
     svSubtitle = options.sv_subtitle || subTitle,
+    svAxisTitle = options.sv_axis_title,
     svBarWidth = options.sv_bar_width || barWidth,
     svPositiveColor = options.sv_positive_color || positiveColor,
     svNegativeColor = options.sv_negative_color || negativeColor,
     cpTitle = options.cp_title,
     cpSubtitle = options.cp_subtitle || subTitle,
+    cpAxisTitle = options.cp_axis_title,
     cpBarWidth = options.cp_bar_width || barWidth,
     cpLineSize = options.cp_line_size || lineSize,
     cpPointSize = options.cp_point_size || pointSize,
@@ -65,34 +68,41 @@ var TIME = options.time,
     cpPointColor = options.cp_point_color || pointColor,
     fiTitle = options.fi_title,
     fiSubtitle = options.fi_subtitle || subTitle,
+    fiAxisTitle = options.fi_axis_title,
     fiBarWidth = options.fi_bar_width || barWidth,
     fiBarColor = options.fi_bar_color || barColor,
     pdTitle = options.pd_title,
     pdSubtitle = options.pd_subtitle || subTitle,
+    pdAxisTitle = options.pd_axis_title,
     pdBarWidth = options.pd_bar_width || barWidth,
     pdLineSize = options.pd_line_size || lineSize,
     pdBarColor = options.pd_bar_color || barColor,
     pdLineColor = options.pd_line_color || lineColor,
     adTitle = options.ad_title,
     adSubtitle = options.ad_subtitle || subTitle,
+    adAxisTitle = options.ad_axis_title,
     adBarWidth = options.ad_bar_width || barWidth,
     adLineSize = options.ad_line_size || lineSize,
     adBarColor = options.ad_bar_color || barColor,
     adLineColor = options.ad_line_color || lineColor,
     rvTitle = options.rv_title,
     rvSubtitle = options.rv_subtitle || subTitle,
+    rvAxisTitle = options.rv_axis_title,
     rvPointSize = options.rv_point_size || pointSize,
     rvPointColor = options.tv_point_color || pointColor,
     fdTitle = options.fd_title,
     fdSubtitle = options.fd_subtitle || subTitle,
+    fdAxisTitle = options.fd_axis_title,
     fdBarWidth = options.fd_bar_width || barWidth,
     fdBarColor = options.fd_bar_color || barColor,
     tvTitle = options.tv_title,
     tvSubtitle = options.tv_subtitle || subTitle,
+    tvAxisTitle = options.tv_axis_title,
     tvPointSize = options.tv_point_size || pointSize,
     tvPointColor = options.tv_point_color || pointColor,
     atTitle = options.at_title,
     atSubtitle = options.at_subtitle || subTitle,
+    atAxisTitle = options.at_axis_title,
     atBarWidth = options.at_bar_width || barWidth,
     atLineSize = options.at_line_size || lineSize,
     atPointSize = options.at_point_size || pointSize,
